import MineFieldLexer;
import java.io.*;
import java.util.*;
import antlr.collections.AST;
import antlr.collections.impl.*;
import antlr.debug.misc.*;
import antlr.*;

class Main {

	static boolean showTree = false;
	static int numProcs =1; 
	static String outfileprefix = "data/minefield";
	static int totalMine = 1;
    public static void main(String[] args) {
		// Use a try/catch block for parser exceptions
		try {
			// if we have at least one command-line argument
			if (args.length > 0 ) {
				System.err.println("Parsing...");

				// for each directory/file specified on the command line
				for(int i=0; i< args.length;i++) {
					if ( args[i].equals("-showtree") ) {
						showTree = true;
					}else if ( args[i].startsWith("-n") ){
						System.out.println("Number of processes = "+args[i].substring(2));
						numProcs = Integer.parseInt(args[i].substring(2));
					}else if ( args[i].startsWith("-o") ){
						System.out.println("output Directory  = "+args[i].substring(2));
						outfileprefix = args[i].substring(2);
					}else if ( args[i].startsWith("-m") ){
/*						if(Integer.parseInt(args[i].substring(2))%1000000 != 0) {
							System.out.println("Please enter multiples of 1,000,000");
							return;
						}*/
						System.out.println("Parsing "+args[i].substring(2)+" mines");
						totalMine = Integer.parseInt(args[i].substring(2));
					}else {
						doFile(new File(args[i])); // parse it
					}
				} 
			}
			else
				System.err.println("Usage: java JavaRecogizer [-showtree] "+
                                   "<directory or file name>");
		}
		catch(Exception e) {
			System.err.println("exception: "+e);
			e.printStackTrace(System.err);   // so we can get stack trace
		}
	}


	// This method decides what action to take based on the type of
	//   file we are looking at
	public static void doFile(File f)
							  throws Exception {
		// If this is a directory, walk each file/dir in that directory
		if (f.isDirectory()) {
			String files[] = f.list();
			for(int i=0; i < files.length; i++)
				doFile(new File(f, files[i]));
		}

		// otherwise, if this is a java file, parse it!
		else 
//if ((f.getName().length()>5) &&
//				f.getName().substring(f.getName().length()-5).equals(".java")) 
			{
			System.err.println("   "+f.getAbsolutePath());
			parseFile(f.getName(), new FileInputStream(f));
		}
	}

	// Here's where we do the real work...
	public static void parseFile(String f, InputStream s)
								 throws Exception {
		try {
			// Create a scanner that reads from the input stream passed to us
			MineFieldLexer lexer = new MineFieldLexer(s);

			// Create a parser that reads from the scanner
			MineFieldRecognizer parser = new MineFieldRecognizer(lexer);

			//pass the number of processes to the parser 
			parser.setNumProcs(numProcs);
			parser.setOutputFilePrefix(outfileprefix);
			parser.setTotalMine(totalMine);
			// start parsing at the compilationUnit rule
			parser.mineFieldUnit();
			
			// do something with the tree
//			doTreeAction(f, parser.getAST(), parser.getTokenNames());
		}
		catch (Exception e) {
			System.err.println("parser exception: "+e);
			e.printStackTrace();   // so we can get stack trace		
		}
	}
	
/*
	public static void doTreeAction(String f, AST t, String[] tokenNames) {
		if ( t==null ) {
            System.out.println("t is null");
            return;
        }
		if ( showTree ) {
			((CommonAST)t).setVerboseStringConversion(true, tokenNames);
			ASTFactory factory = new ASTFactory();
			AST r = factory.create(0,"AST ROOT");
			r.setFirstChild(t);
			ASTFrame frame = new ASTFrame("Java AST", r);
			frame.setVisible(true);
		System.out.println(t.toStringList());
		}
//		JavaTreeParser tparse = new JavaTreeParser();
		try {
//			tparse.compilationUnit(t);
			// System.out.println("successful walk of result AST for "+f);
		}
		catch (ParserException e) {
			System.err.println(e.getMessage());
			e.printStackTrace();
		}

	}
*/
}
